package com.me.brickbuster.entity;

import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.math.Vector2;
import com.badlogic.gdx.physics.box2d.Body;
import com.badlogic.gdx.physics.box2d.BodyDef;
import com.badlogic.gdx.physics.box2d.FixtureDef;
import com.badlogic.gdx.physics.box2d.PolygonShape;
import com.me.brickbuster.entity.powerup.PowerUpType;
import com.me.brickbuster.physics.EntityType;
import com.me.brickbuster.physics.PhysicsBody;
import com.me.brickbuster.state.PlayState;

public class Shield extends Entity implements PhysicsBody {

	public static final float SHIELD_HEIGHT = 0.75f;

	private Body body;

	public Shield(PlayState state) {
		super(state, 0, state.getShieldCount() * SHIELD_HEIGHT);
		createBody();
	}

	@Override
	public void render(SpriteBatch sb, ShapeRenderer sr) {
		sr.begin(ShapeRenderer.ShapeType.Filled);
		sr.setColor(PowerUpType.SHIELD.getColor());
		sr.rect(0, pos.y, PlayState.BOARD_WIDTH, SHIELD_HEIGHT);
		sr.end();
	}

	@Override
	public void update(float dt) {
		if (deleted) {
			((PlayState) state).removeShield(this);
		}
	}

	@Override
	public void createBody() {
		BodyDef brickBody = new BodyDef();
		brickBody.type = BodyDef.BodyType.StaticBody;
		brickBody.position.set(pos.cpy());

		PolygonShape brickShape = new PolygonShape();
		brickShape.setAsBox(PlayState.BOARD_WIDTH/2, SHIELD_HEIGHT/2,
				new Vector2(PlayState.BOARD_WIDTH/2,SHIELD_HEIGHT/2), 0);

		FixtureDef brickFixture = new FixtureDef();
		brickFixture.shape = brickShape;
		brickFixture.friction = 0f;

		brickFixture.filter.categoryBits = EntityType.SHIELD;
		brickFixture.filter.maskBits = EntityType.BALL;

		body = state.world.createBody(brickBody);
		body.createFixture(brickFixture);
		body.setUserData(this);

		brickShape.dispose();
	}

	@Override
	public Body getBody() {
		return body;
	}
}
