package com.me.brickbuster.state;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.math.Vector3;
import com.me.brickbuster.BrickBuster;

public class MenuState extends State {

	private Texture playButton;

	public MenuState(BrickBuster game) {
		super(game);
	}

	@Override
	public void setup() {
		this.playButton = new Texture(Gdx.files.internal("playBtn.png"));
	}

	@Override
	public void render() {
		game.sb.setProjectionMatrix(game.cam.combined);
		game.sb.begin();
		game.sb.setColor(Color.WHITE);
		game.sb.draw(playButton,
					BrickBuster.BOARD_WIDTH/2-playButton.getWidth()/2,
					BrickBuster.BOARD_HEIGHT/2-playButton.getHeight()/2);
		game.sb.end();
		game.sb.setProjectionMatrix(game.cam.combined.cpy().scl(PlayState.PIXEL_PER_METER));
	}

	@Override
	public void update(float dt) {
		if (Gdx.input.justTouched()) {
			Vector3 clickLoc = game.cam.unproject(new Vector3(Gdx.input.getX(), Gdx.input.getY(), 0));
			if (clickLoc.x >= BrickBuster.BOARD_WIDTH/2-playButton.getWidth()/2
					&& clickLoc.x <= BrickBuster.BOARD_WIDTH/2+playButton.getWidth()/2
					&& clickLoc.y >= BrickBuster.BOARD_HEIGHT/2-playButton.getHeight()/2
					&& clickLoc.y <= BrickBuster.BOARD_HEIGHT/2+playButton.getHeight()/2) {
				game.setScreen(new PlayState(game));
				dispose();
			}
		}

		if(Gdx.input.isKeyJustPressed(Input.Keys.F12)) {
			game.setScreen(new EditorState(game));
			dispose();
		}
	}

	@Override
	public void dispose() {
		super.dispose();
		playButton.dispose();
	}
}
